@@ -73,7 +73,7 @@ class Exceptions:
 
 class CodeGuruReviewerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html)
     """
 
@@ -89,14 +89,14 @@ class CodeGuruReviewerClient(BaseClient):
         self,
         *,
         Repository: "RepositoryTypeDef",
-        ClientRequestToken: str = None,
-        Tags: Mapping[str, str] = None,
-        KMSKeyDetails: "KMSKeyDetailsTypeDef" = None
+        ClientRequestToken: str = ...,
+        Tags: Mapping[str, str] = ...,
+        KMSKeyDetails: "KMSKeyDetailsTypeDef" = ...
     ) -> AssociateRepositoryResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#associate_repository)
         """
 
@@ -104,7 +104,7 @@ class CodeGuruReviewerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#can_paginate)
         """
 
@@ -114,12 +114,12 @@ class CodeGuruReviewerClient(BaseClient):
         Name: str,
         RepositoryAssociationArn: str,
         Type: "CodeReviewTypeTypeDef",
-        ClientRequestToken: str = None
+        ClientRequestToken: str = ...
     ) -> CreateCodeReviewResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#create_code_review)
         """
 
@@ -127,17 +127,17 @@ class CodeGuruReviewerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#describe_code_review)
         """
 
     def describe_recommendation_feedback(
-        self, *, CodeReviewArn: str, RecommendationId: str, UserId: str = None
+        self, *, CodeReviewArn: str, RecommendationId: str, UserId: str = ...
     ) -> DescribeRecommendationFeedbackResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#describe_recommendation_feedback)
         """
 
@@ -147,7 +147,7 @@ class CodeGuruReviewerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#describe_repository_association)
         """
 
@@ -157,21 +157,21 @@ class CodeGuruReviewerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#disassociate_repository)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#generate_presigned_url)
         """
 
@@ -179,16 +179,16 @@ class CodeGuruReviewerClient(BaseClient):
         self,
         *,
         Type: TypeType,
-        ProviderTypes: Sequence[ProviderTypeType] = None,
-        States: Sequence[JobStateType] = None,
-        RepositoryNames: Sequence[str] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        ProviderTypes: Sequence[ProviderTypeType] = ...,
+        States: Sequence[JobStateType] = ...,
+        RepositoryNames: Sequence[str] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListCodeReviewsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_code_reviews)
         """
 
@@ -196,42 +196,42 @@ class CodeGuruReviewerClient(BaseClient):
         self,
         *,
         CodeReviewArn: str,
-        NextToken: str = None,
-        MaxResults: int = None,
-        UserIds: Sequence[str] = None,
-        RecommendationIds: Sequence[str] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        UserIds: Sequence[str] = ...,
+        RecommendationIds: Sequence[str] = ...
     ) -> ListRecommendationFeedbackResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_recommendation_feedback)
         """
 
     def list_recommendations(
-        self, *, CodeReviewArn: str, NextToken: str = None, MaxResults: int = None
+        self, *, CodeReviewArn: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListRecommendationsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_recommendations)
         """
 
     def list_repository_associations(
         self,
         *,
-        ProviderTypes: Sequence[ProviderTypeType] = None,
-        States: Sequence[RepositoryAssociationStateType] = None,
-        Names: Sequence[str] = None,
-        Owners: Sequence[str] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        ProviderTypes: Sequence[ProviderTypeType] = ...,
+        States: Sequence[RepositoryAssociationStateType] = ...,
+        Names: Sequence[str] = ...,
+        Owners: Sequence[str] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListRepositoryAssociationsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_repository_associations)
         """
 
@@ -239,7 +239,7 @@ class CodeGuruReviewerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_tags_for_resource)
         """
 
@@ -249,7 +249,7 @@ class CodeGuruReviewerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#put_recommendation_feedback)
         """
 
@@ -257,7 +257,7 @@ class CodeGuruReviewerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#tag_resource)
         """
 
@@ -265,7 +265,7 @@ class CodeGuruReviewerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#untag_resource)
         """
 
@@ -273,7 +273,7 @@ class CodeGuruReviewerClient(BaseClient):
         self, operation_name: Literal["list_repository_associations"]
     ) -> ListRepositoryAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/paginators.html#listrepositoryassociationspaginator)
         """
 
@@ -282,7 +282,7 @@ class CodeGuruReviewerClient(BaseClient):
         self, waiter_name: Literal["code_review_completed"]
     ) -> CodeReviewCompletedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Waiter.CodeReviewCompleted)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Waiter.CodeReviewCompleted)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/waiters.html#codereviewcompletedwaiter)
         """
 
@@ -291,6 +291,6 @@ class CodeGuruReviewerClient(BaseClient):
         self, waiter_name: Literal["repository_association_succeeded"]
     ) -> RepositoryAssociationSucceededWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Waiter.RepositoryAssociationSucceeded)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Waiter.RepositoryAssociationSucceeded)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/waiters.html#repositoryassociationsucceededwaiter)
         """
